@@ -11,10 +11,10 @@
 # 
 getStrikezones <- function(data, facets, strikeFX = FALSE) {
   heights=NULL #ugly hack to comply with R CMD check
-  h <- ldply(strsplit(as.character(data$b_height), "-"), function(x) { as.numeric(x) })
+  h <- plyr::ldply(strsplit(as.character(data$b_height), "-"), function(x) { as.numeric(x) })
   h[,2] <- h[,2]/12
   data$heights <- h[,1] + h[,2]
-  bounds <- ddply(data, c("stand", facets), summarize, height=mean(heights))
+  bounds <- plyr::ddply(data, c("stand", facets), summarise, height=mean(heights))
   righty <- as.numeric(bounds$stand == "R")
   lefty <- as.numeric(bounds$stand == "L")
   bounds$top <- righty*(2.6 + bounds$height*0.136) + lefty*(2 + bounds$height*0.229)
@@ -23,7 +23,7 @@ getStrikezones <- function(data, facets, strikeFX = FALSE) {
   bounds$right <- righty + lefty*0.81
   if (strikeFX) { #adjust vertical pitch locations
     joinby <- unique(c("stand", facets))
-    data2 <- join(data, bounds, by = joinby, type = "inner")
+    data2 <- plyr::join(data, bounds, by = joinby, type = "inner")
     data2$R <- as.numeric(data$stand == "R")
     data2$L <- as.numeric(data$stand == "L")
     data2$tops <- with(data2, R*(2.6 + heights*0.136) + L*(2 + heights*0.229))
